=======
Classes
=======

All classes correspond to one of the `Product Specific Scopus APIs <https://dev.elsevier.com/api_docs.html>`_.  See below links for class reference and examples.

Search APIs
~~~~~~~~~~~

.. toctree::
    :maxdepth: 1

    classes/AffiliationSearch.rst
    classes/AuthorSearch.rst
    classes/ScopusSearch.rst

Retrieval APIs
~~~~~~~~~~~~~~

.. toctree::
    :maxdepth: 1

    classes/AbstractRetrieval.rst
    classes/AffiliationRetrieval.rst
    classes/AuthorRetrieval.rst

Metadata APIs
~~~~~~~~~~~~~

.. toctree::
    :maxdepth: 1

    classes/CitationOverview.rst
    classes/PlumXMetrics.rst
    classes/SerialSearch.rst
    classes/SerialTitle.rst
    classes/SubjectClassifications.rst

One other Metadata API, the Citations Count Metadata API, is not implemented yet.
